package com.isu.gaswellwatch.modbus.data.decode.impl;

import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Map;

/**
 * 本地日期类型解析器
 *
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/11/25 11:51
 */
@Component(LocalDateDecodeHandler.NAME + DecodeHandler.DECODE_NAME)
public class LocalDateDecodeHandler implements DecodeHandler {
    public static final String NAME = "localDate";

    public static final DateTimeFormatter IN_FORMATTER = DateTimeFormatter.ofPattern("yyyy-M-d");
    public static final DateTimeFormatter OUT_FORMATTER = DateTimeFormatter.ofPattern("yyyy-MM-dd");


    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        if (StringUtils.isBlank(value)) {
            return value;
        }
        return LocalDate.parse(value, IN_FORMATTER).format(OUT_FORMATTER);
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(this.decode(commandPointMap, point.getValue()));
    }

}
