package com.isu.gaswellwatch.vo.command.scss;

import com.isu.gaswellwatch.dto.modbus.ModbusCommandDto;
import com.isu.gaswellwatch.vo.command.Command;
import com.isu.gaswellwatch.vo.command.Timing;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.SuperBuilder;
import org.apache.commons.lang3.StringUtils;

import java.io.Serial;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

/**
 * 套压模式
 *
 * @author <a href="mailto:shilong.wang@alpha-ess.com">王仕龙</a>
 * 2024/12/10 17:01
 */
@Getter
@Setter
@SuperBuilder
public class CasingMode extends Command implements Timing {
    @Serial
    private static final long serialVersionUID = -6609483152571838191L;
    /**
     * 开井套压
     * 152
     */
    @NotNull(message = "开井套压不能为空")
    private BigDecimal wellOpenPressureValue = BigDecimal.ZERO;
    /**
     * 关井套压
     * 160
     */
    @NotNull(message = "关井套压不能为空")
    private BigDecimal wellClosePressureValue = BigDecimal.ZERO;
    /**
     * 最小关井时间
     * 166
     */
    @NotBlank(message = "最小关井时间不能为空，格式：HH:mm:ss")
    private String minWellCloseTimeDuration;
    /**
     * 最大关井时间
     * 168
     */
    @NotBlank(message = "最大关井时间不能为空，格式：HH:mm:ss")
    private String maxWellCloseTimeDuration;

    public CasingMode() {
        this.setCode("SCSS.CASING_MODE");
    }


    @Override
    protected Collection<ModbusCommandDto> builderModbusCommand() {
        List<ModbusCommandDto> resultList = new ArrayList<ModbusCommandDto>(3);
        // 地址码  功能码  起始地址  连续长度  连续字长    控制模式
        // 01     10     0032    0002     04        6(00000006, 6：套压(开)-套压(关)模式)
        resultList.add(ModbusCommandDto.builder().command("0110003200020400000006").length(16).build());

        StringBuilder command = new StringBuilder(250);
        // 地址码  功能码  起始地址  连续长度  连续字长
        // 01     10     0098    0002     04
        command.append("01100098000204");
        command.append(StringUtils.leftPad(Long.toHexString(this.wellOpenPressureValue.multiply(ONE_HUNDRED).intValue()), 8, "0"));
        resultList.add(ModbusCommandDto.builder().command(command.toString()).length(16).build());

        command.setLength(0);
        // 地址码  功能码  起始地址  连续长度  连续字长
        // 01     10     00A0    0002     04
        command.append("011000A0000204");
        command.append(StringUtils.leftPad(Long.toHexString(this.wellClosePressureValue.multiply(ONE_HUNDRED).intValue()), 8, "0"));
        resultList.add(ModbusCommandDto.builder().command(command.toString()).length(16).build());

        command.setLength(0);
        // 地址码  功能码  起始地址  连续长度  连续字长
        // 01     10     00A6    0004     08
        command.append("011000A6000204");
        command.append(StringUtils.leftPad(Long.toHexString(this.toSeconds(this.minWellCloseTimeDuration)), 8, "0"));
        command.append(StringUtils.leftPad(Long.toHexString(this.toSeconds(this.maxWellCloseTimeDuration)), 8, "0"));
        resultList.add(ModbusCommandDto.builder().command(command.toString()).length(16).build());

        return resultList;
    }
}